import { loadRestJsonErrorCode, parseJsonBody as parseBody, parseJsonErrorBody as parseErrorBody } from "@aws-sdk/core";
import { requestBuilder as rb } from "@smithy/core";
import { _json, collectBody, expectNonNull as __expectNonNull, expectObject as __expectObject, map, serializeFloat as __serializeFloat, take, withBaseException, } from "@smithy/smithy-client";
import { SageMakerMetricsServiceException as __BaseException } from "../models/SageMakerMetricsServiceException";
export const se_BatchPutMetricsCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/BatchPutMetrics");
    let body;
    body = JSON.stringify(take(input, {
        MetricData: (_) => se_RawMetricDataList(_, context),
        TrialComponentName: [],
    }));
    b.m("PUT").h(headers).b(body);
    return b.build();
};
export const de_BatchPutMetricsCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Errors: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
const de_CommandError = async (output, context) => {
    const parsedOutput = {
        ...output,
        body: await parseErrorBody(output.body, context),
    };
    const errorCode = loadRestJsonErrorCode(output, parsedOutput.body);
    const parsedBody = parsedOutput.body;
    return throwDefaultError({
        output,
        parsedBody,
        errorCode,
    });
};
const throwDefaultError = withBaseException(__BaseException);
const se_RawMetricData = (input, context) => {
    return take(input, {
        MetricName: [],
        Step: [],
        Timestamp: (_) => _.getTime() / 1000,
        Value: __serializeFloat,
    });
};
const se_RawMetricDataList = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return se_RawMetricData(entry, context);
    });
};
const deserializeMetadata = (output) => ({
    httpStatusCode: output.statusCode,
    requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
    extendedRequestId: output.headers["x-amz-id-2"],
    cfId: output.headers["x-amz-cf-id"],
});
const collectBodyString = (streamBody, context) => collectBody(streamBody, context).then((body) => context.utf8Encoder(body));
const isSerializableHeaderValue = (value) => value !== undefined &&
    value !== null &&
    value !== "" &&
    (!Object.getOwnPropertyNames(value).includes("length") || value.length != 0) &&
    (!Object.getOwnPropertyNames(value).includes("size") || value.size != 0);
