import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { SageMakerMetricsClientResolvedConfig } from "../SageMakerMetricsClient";
/**
 * @internal
 */
export interface SageMakerMetricsHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface SageMakerMetricsHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<SageMakerMetricsClientResolvedConfig, HandlerExecutionContext, SageMakerMetricsHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultSageMakerMetricsHttpAuthSchemeParametersProvider: (config: SageMakerMetricsClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<SageMakerMetricsHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface SageMakerMetricsHttpAuthSchemeProvider extends HttpAuthSchemeProvider<SageMakerMetricsHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultSageMakerMetricsHttpAuthSchemeProvider: SageMakerMetricsHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: SageMakerMetricsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: SageMakerMetricsHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
